summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2009-09-13 18:25:37 +0000
committerChris Lattner <sabre@nondot.org>2009-09-13 18:25:37 +0000
commit70a54c07a0807bf89d1a8b4414e53298c376eb61 (patch)
tree60f51fb27e18daf80678cda1acb6b8becba00a06 /include
parent4afcedfad11555e2c755a31eb04c0e5bdbb2a4a1 (diff)
downloadllvm-70a54c07a0807bf89d1a8b4414e53298c376eb61.tar.gz
llvm-70a54c07a0807bf89d1a8b4414e53298c376eb61.tar.bz2
llvm-70a54c07a0807bf89d1a8b4414e53298c376eb61.tar.xz
replace printBasicBlockLabel with EmitBasicBlockStart,
now that printBasicBlockLabel is only used for starting a MBB. This allows elimination of a bunch of arguments. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@81684 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/CodeGen/AsmPrinter.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/include/llvm/CodeGen/AsmPrinter.h b/include/llvm/CodeGen/AsmPrinter.h
index cd30b39e36..65090adfc6 100644
--- a/include/llvm/CodeGen/AsmPrinter.h
+++ b/include/llvm/CodeGen/AsmPrinter.h
@@ -350,12 +350,11 @@ namespace llvm {
/// block label.
MCSymbol *GetMBBSymbol(unsigned MBBID) const;
- /// printBasicBlockLabel - This method prints the label for the specified
- /// MachineBasicBlock
- void printBasicBlockLabel(const MachineBasicBlock *MBB,
- bool printAlign = false,
- bool printColon = false,
- bool printComment = true) const;
+ /// EmitBasicBlockStart - This method prints the label for the specified
+ /// MachineBasicBlock, an alignment (if present) and a comment describing
+ /// it if appropriate.
+ void EmitBasicBlockStart(const MachineBasicBlock *MBB,
+ bool printColon = true) const;
protected:
/// EmitZeros - Emit a block of zeros.
///